==> pyiArduinoI2Cmotor-0.0.2.tar.gz: pyiArduinoI2Cmotor-0.0.2/pyiArduinoI2Cmotor/examples/GetError.py <==
# ДАННЫЙ ПРИМЕР ИНФОРМИРУЕТ ОБ ОШИБКЕ СКОРОСТИ:     #
                                                    #
from pyiArduinoI2Cmotor import *                    #   Подключаем библиотеку для работы с мотором I2C-flash.
mot = pyiArduinoI2Cmotor(0x09)                      #   Объявляем объект mot для работы с функциями и методами библиотеки pyiArduinoI2Cmotor, указывая адрес модуля на шине I2C.
                                                    #   Если объявить объект без указания адреса (mot = pyiArduinoI2Cmotor ), то адрес будет найден автоматически.
while True:                                         #
    print("Запускаем мотор.")                       #   Выводим сообщение о запуске мотора.
    mot.setSpeed(60, MOT_RPM)                       #   Запускаем мотор на скорости 60 об/мин.

    if mot.getError()==MOT_ERR_SPD:                 #   Если есть ошибка скорости (указанная скорость не соответствует действительной), то ...
        print("Набор заданной скорости.", end="")   #   Выводим сообщение.

        while(mot.getError()==MOT_ERR_SPD):         #   Пока сохраняется ошибка скорости.
            print(".", end = "")
            sleep(.1)                               #   Выводим точку с задержкой по времени.

    print("\r\nСкорость набрана.")
    sleep(.5)                                       #   Приостанавливаем выполнение скетча на 500 миллисекунд.
    print("Останавливаем мотор.")                   #   Выводим сообщение.
    mot.setStop()                                   #   Останавливаем мотор.
    print("====================")                   #   Выводим разделитель.
    sleep(.5)                                       #   Приостанавливаем выполнение скетча на 500 миллисекунд.

==> pyiArduinoI2Cmotor-0.0.4.tar.gz: pyiArduinoI2Cmotor-0.0.4/pyiArduinoI2Cmotor/examples/GetError.py <==
# ДАННЫЙ ПРИМЕР ИНФОРМИРУЕТ ОБ ОШИБКЕ СКОРОСТИ:     #
                                                    #
from pyiArduinoI2Cmotor import *                    #   Подключаем библиотеку для работы с мотором I2C-flash.
mot = pyiArduinoI2Cmotor(0x09)                      #   Объявляем объект mot для работы с функциями и методами библиотеки pyiArduinoI2Cmotor, указывая адрес модуля на шине I2C.
                                                    #   Если объявить объект без указания адреса (mot = pyiArduinoI2Cmotor ), то адрес будет найден автоматически.
while True:                                         #
    print("Запускаем мотор.")                       #   Выводим сообщение о запуске мотора.
    mot.setSpeed(60, MOT_RPM)                       #   Запускаем мотор на скорости 60 об/мин.

    if mot.getError()==MOT_ERR_SPD:                 #   Если есть ошибка скорости (указанная скорость не соответствует действительной), то ...
        print("Набор заданной скорости.", end="")   #   Выводим сообщение.

        while(mot.getError()==MOT_ERR_SPD):         #   Пока сохраняется ошибка скорости.
            print(".", end = "")
            sleep(.1)                               #   Выводим точку с задержкой по времени.

    print("\r\nСкорость набрана.")
    sleep(.5)                                       #   Приостанавливаем выполнение скрипта на 500 миллисекунд.
    print("Останавливаем мотор.")                   #   Выводим сообщение.
    mot.setStop()                                   #   Останавливаем мотор.
    print("====================")                   #   Выводим разделитель.
    sleep(.5)                                       #   Приостанавливаем выполнение скрипта на 500 миллисекунд.
